# libpythonpro2
Módulo para exemplificar construção de projetos python no curso pytools.

Nesse curso é ensinado a como contribuir com projetos de código aberto.

link do curso [Python Pro](https://pythonpro.com.br/)

[![Build Status](https://travis-ci.org/luizfernandoliveira/libpythonpro.svg?branch=master)](https://travis-ci.org/luizfernandoliveira/libpythonpro)
[![Updates](https://pyup.io/repos/github/luizfernandoliveira/libpythonpro2/shield.svg)](https://pyup.io/repos/github/luizfernandoliveira/libpythonpro2/)
[![Python 3](https://pyup.io/repos/github/luizfernandoliveira/libpythonpro2/python-3-shield.svg)](https://pyup.io/repos/github/luizfernandoliveira/libpythonpro2/)

Suportada a versão 3 de Python.

Para instalar:

```console
py -3 -m venv .venv
.\.venv\Scrips\activate
pip install -r requirements-dev.txt
```

Para conferir qualidade do código:

```console
flake8
```
Tópicos a serem abordados:
1. Git
2. Virtualenv
3. Pip
